pub enum NlaParseMode {
Strict,
Relaxed,
}Expand description
Describes how to handle errors when parsing attributes.
Variants
Strict
Any attribute parsing errors result in a failure of the entire message
parsing operation. Corresponds to the NETLINK_GET_STRICT_CHK option.
Relaxed
Attribute parsing errors do not impact the success of message parsing. Attributes that failed to parse are ignored.