ParseableParametrized

Trait ParseableParametrized 

pub trait ParseableParametrized<T, P>
where Self: Sized, T: ?Sized,
{ type Error; // Required method fn parse_with_param(buf: &T, params: P) -> Result<Self, Self::Error>; }
A Parseable type can be used to deserialize data from the type T for which it is implemented.

Required Associated Types

Required Methods

fn parse_with_param(buf: &T, params: P) -> Result<Self, Self::Error>

Deserialize the current type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors